# Copyright (C) 2024 - 2025 ANSYS, Inc. and/or its affiliates.
# SPDX-License-Identifier: MIT
#
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

"""
.. _ref_backgroundplotter:

========================
Use a PyVista Qt backend
========================

PyVista Qt is a package that extends the PyVista functionality through the
usage of Qt. Qt applications operate in a separate thread than VTK, you can
simultaneously have an active VTK plot and a non-blocking Python session.

This example shows how to use the PyVista Qt backend to create a plotter
"""

import pyvista as pv

from ansys.tools.visualization_interface import Plotter
from ansys.tools.visualization_interface.backends.pyvista import PyVistaBackend

#########################
# Open a pyvistaqt window
# =======================
# .. code-block:: python
#
#   cube = pv.Cube()
#   pv_backend = PyVistaBackend(use_qt=True, show_qt=True)
#   pl = Plotter(backend=pv_backend)
#   pl.plot(cube)
#   pl.backend.enable_widgets()
#   pv_backend.scene.show()


#####################
# Parallel VTK window
# ===================

sphere = pv.Sphere()

pl_parallel = Plotter()
pl_parallel.plot(sphere)
pl_parallel.show()

############################
# Close the pyvistaqt window
# ==========================
# .. code-block:: python
#
#   pv_backend.close()

###########################################
# Integrate the plotter in a Qt application
# =========================================
# .. code-block:: python
#
#   pv_backend = PyVistaBackend(use_qt=True, show_qt=False)
#   pv_backend.enable_widgets()
#
#   # You can use this plotter in a Qt application
#   pl = pv_backend.scene
